/*
 * <one line to give the library's name and an idea of what it does.>
 * Copyright 2013  Vishesh Handa <me@vhanda.in>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License or (at your option) version 3 or any later version
 * accepted by the membership of KDE e.V. (or its successor approved
 * by the membership of KDE e.V.), which shall act as a proxy
 * defined in Section 14 of version 3 of the license.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef APPLET_H
#define APPLET_H

#include <Plasma/PopupApplet>
#include <Plasma/DeclarativeWidget>

class Applet : public Plasma::PopupApplet
{
    Q_OBJECT
public:
    Applet(QObject* parent, const QVariantList& args);
    virtual ~Applet();

    virtual void init();
    virtual QGraphicsWidget* graphicsWidget();

    virtual void createConfigurationInterface(KConfigDialog* parent);

    Q_INVOKABLE QPoint tooltipPosition(QGraphicsObject* item, int tipWidth, int tipHeight);

public slots:
    bool isTopEdge() const;
    bool isBottomEdge() const;

    bool isShown() const;

signals:
    void popupEventSignal(bool shown);
    void settingsChanged();

protected:
    virtual void popupEvent(bool show);

private:
    Plasma::DeclarativeWidget* m_declarativeWidget;
};

K_EXPORT_PLASMA_APPLET(milou_applet, Applet)

#endif // APPLET_H
